@@ -13,7 +13,8 @@ enum {
   LOG_ERROR,   /*Other runtime errors or unexpected conditions */
   LOG_WARN,    /*'Almost' errors, other runtime situations that are undesirable or unexpected */
   LOG_USER_ACTION,
-  LOG_NETWORK
+  LOG_NETWORK, /*Networking info, e.g. new connection establishments, game starting etc. */
+  LOG_NETWORK_DEBUG /* Networking debug */
 };
 
 void cem_add_to_log(char *message,int type);
