@@ -50,7 +50,7 @@ gboolean singinggame_cross_click(TangleButton* tanglebutton, gpointer sequencer)
 	return FALSE;
 }
 
-void singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequencer, ClutterActor* parent) {
+void singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequencer, ClutterActor* parent, gboolean seekable) {
 	ClutterActor *container = tangle_widget_new();
 	ClutterActor* texture_color;
 	ClutterActor* texture_image;
@@ -84,6 +84,7 @@ void singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequencer, Clut
 	
 	
 	cursor = jammo_cursor_new(sequencer, container);
+	g_object_set(cursor, "seekable", seekable, NULL);
 	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
 	clutter_actor_set_position(cursor, 0.0, 480.0-height-2);
 	clutter_actor_set_size(cursor, 800.0, height+4);
@@ -164,7 +165,7 @@ static void on_sequencer_stopped_playback(JammoSequencer* sequencer_old, gpointe
 
 static void say_now_you_hear_own_singing(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer sequencer){
 	if (interrupted){
-		singinggame_start_sequencer(JAMMO_SEQUENCER(sequencer));
+		start_sequencer(NULL, NULL, interrupted, sequencer);
 		return;
 	}
 
@@ -238,7 +239,7 @@ void on_sequencer_stopped_recording(JammoSequencer* sequencer_old, gpointer user
 	//g_free(loaded_filename);
 
 	ClutterColor green = { 0, 255, 0, 128 };
-	singinggame_add_cursor(&green, sequencer, view);
+	singinggame_add_cursor(&green, sequencer, view, TRUE);
 
 
 	chum_set_state_of_chum(SCREEN_PLAY_RECORDED);
@@ -253,7 +254,10 @@ void singinggame_force_reinit_songs(){
 }
 
 static void say_this_too(JammoMentor* mentor, const gchar*speech, gboolean interrupted, gpointer data){
-	if (!interrupted){
+	if (interrupted){
+	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
+	}
+	else {
 		jammo_mentor_speak(jammo_mentor_get_default(),(gchar*)data);
 	}
 }
