@@ -217,8 +217,17 @@ int main(int argc, char** argv) {
 
 	srand (time (NULL)); //We will use rand()
 
+	//Name of binary
+	application_path = g_strdup(argv[0]);
+	application_name = basename(application_path);
+
+
 #ifdef N900
-	osso_context = osso_initialize("org.umsic.jammo", VERSION, 0, NULL);
+	if (!strcmp(application_name,"jammo7_12"))
+		osso_context = osso_initialize("org.umsic.jammo7_12", VERSION, 0, NULL);
+	else
+		osso_context = osso_initialize("org.umsic.jammo3_6", VERSION, 0, NULL);
+
 	g_assert(osso_context != NULL);
 
 	osso_display_state_on(osso_context);
@@ -285,25 +294,16 @@ int main(int argc, char** argv) {
 	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
 
 	gchar* lang = getenv ("LANG");
-	gchar* lang2="";
 	printf("LANG='%s'\n",lang);
-	if (strncmp (lang,"fi_FI",5)==0){
-		lang2 = "mentor_speech/finnish";
-	}
-	else if (strncmp (lang,"ge_GE",5)==0){
-		lang2 = "mentor_speech/german";
-	}
-	else if (strncmp (lang,"en_EN",5)==0){
-		lang2 = "mentor_speech/english";
-	}
-	printf("language path='%s'\n",lang2);
-	jammo_mentor_set_language(jammo_mentor_get_default(),lang2);
+
+	gchar* lang2=g_strndup (lang,5); //omit charset.
+	gchar* path = g_strdup_printf("mentor_speech/%s",lang2);
+
+	printf("language path='%s'\n",path);
+	jammo_mentor_set_language(jammo_mentor_get_default(),path);
+	g_free(path);
 
 
-
-	application_path = g_strdup(argv[0]);
-	application_name = basename(application_path);
-	
 	if (!strcmp(application_name,"jammo3_6")) { //start jammo 3-6 years
 		printf("Starting 3-6 years game\n");
 		g_timeout_add(10000, door_timeouts,NULL); //10 seconds and door will be opened automatically
