@@ -174,14 +174,14 @@ void gems_service_collaboration_handle_action_midi(gems_components* data, gems_c
 	{
 		// note
 		note = element->nwbuffer[position];
-		position++;
+		position = position + sizeof (unsigned char);
 		// timestamp
 		timestamp = gems_connection_get_64(element,position);
 		position = position + sizeof(guint64);
 		// type
 		eventtype = gems_connection_get_32(element,position);
 		position = position + sizeof(guint32);
-		jammomidi_store_event_to_glist(&eventlist, note, timestamp, eventtype);
+		jammomidi_store_event_to_glist(&eventlist, note, eventtype, timestamp);
 	}
 
 	// Log and call CHUM with midi list
@@ -191,9 +191,11 @@ void gems_service_collaboration_handle_action_midi(gems_components* data, gems_c
 		cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 
-		//chum_callback_midi_replace(data->service_collaboration->collaboration_game, user_id,instrument_id, eventlist);
-
+		chum_callback_midi_list(data->service_collaboration->collaboration_game, user_id,instrument_id, GEMS_EVENTLIST_REPLACE, eventlist);
 	}
+
+	// free list
+	jammomidi_free_glist(&eventlist);
 }
 
 void gems_service_collaboration_handle_action_slider(gems_components* data, gems_connection* element)
@@ -233,7 +235,7 @@ void gems_service_collaboration_handle_action_slider(gems_components* data, gems
 		// type
 		eventtype = gems_connection_get_32(element,position);
 		position = position + sizeof(guint32);
-		jammo_slider_event_store_event_to_glist(&eventlist, freq, timestamp, eventtype);
+		jammo_slider_event_store_event_to_glist(&eventlist, freq, eventtype, timestamp);
 	}
 
 	// Log and call CHUM with midi list
@@ -243,9 +245,11 @@ void gems_service_collaboration_handle_action_slider(gems_components* data, gems
 		cem_add_to_log(logmsg,LOG_NETWORK_DEBUG);
 		g_free(logmsg);
 
-		//chum_callback_midi_replace(data->service_collaboration->collaboration_game, user_id,instrument_id, eventlist);
-
+		chum_callback_slider_event_list(data->service_collaboration->collaboration_game, user_id,instrument_id, GEMS_EVENTLIST_REPLACE, eventlist);
 	}
+	
+	// free list
+	jammo_slider_event_free_glist(&eventlist);
 }
 
 void gems_service_collaboration_handle_action_confirmed(gems_components* data, gems_connection* element)
