@@ -107,19 +107,19 @@ static GObject* jammo_slider_track_constructor(GType type, guint n_properties, G
 	g_object_set(G_OBJECT(slider_track->priv->slider), "instrument", slider_nro, NULL);
 
 	if (slider_nro == JAMMO_SLIDER_TYPE_KARPLUS) {
-			g_object_set(G_OBJECT(slider_track->priv->slider), "attack", 100, NULL);
-			g_object_set(G_OBJECT(slider_track->priv->slider), "decay", 100, NULL);
+			g_object_set(G_OBJECT(slider_track->priv->slider), "attack", 0.002, NULL);
+			g_object_set(G_OBJECT(slider_track->priv->slider), "decay", 0.002, NULL);
 			g_object_set(G_OBJECT(slider_track->priv->slider), "sustain", 1.0, NULL);
-			g_object_set(G_OBJECT(slider_track->priv->slider), "release", 100, NULL);
+			g_object_set(G_OBJECT(slider_track->priv->slider), "release", 0.002, NULL);
 			// filter is low-pass by default
 			g_object_set(slider_track->priv->filter, "cutoff", 10000.0, NULL);
 	}
 	
 	if (slider_nro == JAMMO_SLIDER_TYPE_FM_MODULATION) {
-			g_object_set(G_OBJECT(slider_track->priv->slider), "attack", 15000, NULL);
-			g_object_set(G_OBJECT(slider_track->priv->slider), "decay", 2000, NULL);
+			g_object_set(G_OBJECT(slider_track->priv->slider), "attack", 0.34, NULL);
+			g_object_set(G_OBJECT(slider_track->priv->slider), "decay", 0.045, NULL);
 			g_object_set(G_OBJECT(slider_track->priv->slider), "sustain", 0.8, NULL);
-			g_object_set(G_OBJECT(slider_track->priv->slider), "release", 5000, NULL);
+			g_object_set(G_OBJECT(slider_track->priv->slider), "release", 0.11, NULL);
 			// filter low-pass by default
 			g_object_set(slider_track->priv->filter, "cutoff", 1000.0, NULL);
 	}
